@@ -112,10 +112,19 @@ class Hardware(BaseHardware):
           elif bid >= 0 and data[10] != bid:
             pass
           else:
+            if data[10] == 6:	# Hermes Lite
+              num_rx = int(data[0x13])
+              if num_rx < 1:
+                num_rx = 1
+              elif num_rx > 10:
+                num_rx = 10
+            else:
+              num_rx = 1
             dta = data[3:10]
             dta.append(data[0x15])
+            dta.append(num_rx)
             dta.append(data[10])
-            st = 'Capture from Hermes device: Mac %2x:%2x:%2x:%2x:%2x:%2x, Code version %d.%d, ID %d' % tuple(dta)
+            st = 'Capture from Hermes: Mac %2x:%2x:%2x:%2x:%2x:%2x, Code version %d.%d, Rx %d, ID %d' % tuple(dta)
             self.hermes_mac = data[3:9]
             self.hermes_ip = addr[0]
             self.hermes_code_version = data[9]
