@@ -46,25 +46,6 @@ import quisk_hardware_model as quisk_hardware
 # import n2adr.quisk_widgets as quisk_widgets
 quisk_widgets = None
 
-# This is a dictionary of data items that are in the radio_dict but are not defined below in the sections.
-# The value is a tuple (format name, default value).
-name2format = {
-  "digital_rx1_name":('text', ''), "digital_rx2_name":('text', ''), "digital_rx3_name":('text', ''),
-  "digital_rx4_name":('text', ''), "digital_rx5_name":('text', ''), "digital_rx6_name":('text', ''),
-  "digital_rx7_name":('text', ''), "digital_rx8_name":('text', ''), "digital_rx9_name":('text', ''),
-  "win_digital_rx1_name":('text', ''), "win_digital_rx2_name":('text', ''), "win_digital_rx3_name":('text', ''),
-  "win_digital_rx4_name":('text', ''), "win_digital_rx5_name":('text', ''), "win_digital_rx6_name":('text', ''),
-  "win_digital_rx7_name":('text', ''), "win_digital_rx8_name":('text', ''), "win_digital_rx9_name":('text', ''),
-  "lin_digital_rx1_name":('text', ''), "lin_digital_rx2_name":('text', ''), "lin_digital_rx3_name":('text', ''),
-  "lin_digital_rx4_name":('text', ''), "lin_digital_rx5_name":('text', ''), "lin_digital_rx6_name":('text', ''),
-  "lin_digital_rx7_name":('text', ''), "lin_digital_rx8_name":('text', ''), "lin_digital_rx9_name":('text', ''),
-}
-
-def __getattr__(name):	# provide default values for some names
-  if name in name2format:
-    return name2format[name][1]
-  raise AttributeError("'conf' object has no attribute '%s'" % name)
-
 
 
 ################ Receivers SoftRock USB, Devices controlled by USB that capture samples from a sound card, and (for Tx) play samples to a sound card
@@ -1238,9 +1219,11 @@ invertSpectrum = 0
 # For FM transmit, this is the modulation index.
 modulation_index = 1.67
 
-## pulse_audio_verbose_output		Debug sound, integer
-# Use 1 to turn on debug and status messages for all sound systems including PulseAudio.
-# This allows for debugging of both devices and performance.
+## pulse_audio_verbose_output		Debug level, integer
+# This controls how much debug information to print to the file quisk_logfile.txt
+# and to the debug screen.
+# Use 0 to turn off all debug information except for serious errors. The debug screen will not appear.
+# Use 1 or 2 for more debug information.
 # Changes are immediate (no need to restart).
 pulse_audio_verbose_output = 0
 #pulse_audio_verbose_output = 1
@@ -1377,10 +1360,11 @@ hamlib_com2_name = ""
 ## hot_key_ptt1		PTT shortcut key 1, keycode
 # Set a keyboard shortcut that will press the PTT button.
 # For a regular key, use the ord() of the key.  For example, ord('a') or ord('b').  For the space bar
-# use ord(' ').  Then restart Quisk.
+# use ord(' ').
 # If you do not want a hot key, set this to None.
 # Do not choose a key that interferes with other features
 # on your system such as system menus.
+# Changes are immediate (no need to restart). But exit the config screen to test.
 hot_key_ptt1 = None
 #hot_key_ptt1 = ord(' ')
 #hot_key_ptt1 = ord('z')
@@ -1389,8 +1373,9 @@ hot_key_ptt1 = None
 
 ## hot_key_ptt2		PTT shortcut key 2, keycode
 # If the Control or Shift key must be pressed too, set that key modifier here.
-# Otherwise, set NORMAL here.
-# For example, if you want control-A, set CTRL in "PTT Key 2", and ord('a') in "PTT Key 1".
+# Otherwise, set wx.ACCEL_NORMAL here.
+# For example, if you want control-A, set wx.ACCEL_CTRL in "PTT Key 2", and ord('a') in "PTT Key 1".
+# Changes are immediate (no need to restart). But exit the config screen to test.
 hot_key_ptt2 = wx.ACCEL_NORMAL
 #hot_key_ptt2 = wx.ACCEL_CTRL
 #hot_key_ptt2 = wx.ACCEL_SHIFT
@@ -1651,11 +1636,15 @@ use_fast_sound = False
 
 ## lin_quisk_serial_port			Quisk serial port, text
 # This is the serial port used for a CW key and a PTT connection.
+# Changes are immediate (no need to restart).
+lin_quisk_serial_port = ""
 #lin_quisk_serial_port = "/dev/ttyUSB0"
 #lin_quisk_serial_port = "/dev/ttyUSB1"
 
 ## win_quisk_serial_port			Quisk serial port, text
 # This is the serial port used for a CW key and a PTT connection.
+# Changes are immediate (no need to restart).
+win_quisk_serial_port = ""
 #win_quisk_serial_port = "COM6"
 #win_quisk_serial_port = "COM7"
 
@@ -1665,6 +1654,7 @@ quisk_serial_port = ""
 # You can use the CTS signal of the serial port for a CW key or for push-to-talk PTT.
 # If "when low", the CW key or PTT is asserted (transmitting) if the voltage on the pin is low,
 # and similarly for "when high".
+# Changes are immediate (no need to restart).
 quisk_serial_cts = "None"
 #quisk_serial_cts = "CW when high"
 #quisk_serial_cts = "CW when low"
@@ -1675,6 +1665,7 @@ quisk_serial_cts = "None"
 # You can use the DSR signal of the serial port for a CW key or for push-to-talk PTT.
 # If "when low", the CW key or PTT is asserted (transmitting) if the voltage on the pin is low,
 # and similarly for "when high".
+# Changes are immediate (no need to restart).
 quisk_serial_dsr = "None"
 #quisk_serial_dsr = "CW when high"
 #quisk_serial_dsr = "CW when low"
