@@ -222,6 +222,8 @@ class SliderBoxH:
   """A horizontal control with a slider and text with a value.  The text must have a %d or %f if display is True."""
   def __init__(self, parent, text, init, themin, themax, handler, display, pos, width, scale=1):
     self.text = text
+    self.themin = themin
+    self.themax = themax
     self.handler = handler
     self.display = display
     self.scale = scale
@@ -270,6 +272,18 @@ class SliderBoxH:
     # Set slider visual position; does not call handler
     self.slider.SetValue(value)
     self.OnScroll()
+  def GetDecValue(self):	# Return the value 0.0 to 1.0
+    return float(self.slider.GetValue() - self.themin) / (self.themax - self.themin)
+  def SetDecValue(self, value, do_cmd=True):	# Set the value with a decimal 0.0 to 1.0
+    if value < 0.0:
+      value = 0.0
+    elif value > 1.0:
+      value = 1.0
+    value = value * (self.themax - self.themin) + self.themin
+    value = int(value + 0.5)
+    self.slider.SetValue(value)
+    if do_cmd:
+      self.handler(None)
 
 class SliderBoxHH(SliderBoxH, wx.BoxSizer):
   """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
@@ -621,6 +635,19 @@ class QuiskRepeatbutton(QuiskButtons, wx.lib.buttons.GenButton):
       self.SendCommand(self.command)
   def OnButton(self, event):
     pass	# button command not used
+  def Shortcut(self, event, button_name=None):
+    if not self.IsEnabled():
+      return
+    if button_name == "_end_":
+      self.repeat_state = 0
+      self.timer.Stop()
+      self.SendCommand(self.up_command)
+    else:
+      self.shift = False
+      self.control = False
+      self.SendCommand(self.command)
+      self.repeat_state = 1		# first button push
+      self.timer.Start(milliseconds=300, oneShot=True)
 
 class QuiskCheckbutton(QuiskButtons, wx.lib.buttons.GenToggleButton):
   """A button that pops up and down, and changes color with each push."""
@@ -1345,6 +1372,8 @@ class RadioBtnPopup:
       event.SetEventObject(self.first_button)
       self.pop_command(event)
     self.first_button.direction = direc
+  def GetButtons(self):
+    return self.RbDialog.RbGroup.GetButtons()
   def Refresh(self):
     pass
   def ChangeSlider(self, slider_value):
@@ -1361,6 +1390,8 @@ class RadioBtnPopup:
     return self.parent
   def GetSize(self):
     return self.first_button.GetSize()
+  def Shortcut(self, event, button_name=None):
+    self.SetLabel(button_name, True)
 
 class FreqSetter(wx.TextCtrl):
   def __init__(self, parent, x, y, label, fmin, fmax, freq, command):
